<?xml version='1.0' encoding="UTF-8" ?>
<!--
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-->

<!DOCTYPE xsl:stylesheet
  SYSTEM "mmlents/windob.dtd"
[
  <!ENTITY % table_braille PUBLIC "table braille" "./tablesBraille/Brltab.ent">
  %table_braille;
  <!ENTITY quad    "&ThickSpace;"> <!-- espace -->
  <!ENTITY neq     "&ne;"> <!-- different de -->
  <!ENTITY epsilon "&epsiv;"> <!-- epsilon -->
  <!ENTITY empty "&emptyv;"> <!-- endemble vide -->
  <!ENTITY ldots   "&mldr;"> <!-- points de suspension -->
  <!ENTITY hat     "&Hat;"> <!-- signe d'angle -->
  <!ENTITY espace  "&#254;"><!-- espace à generer-->
  <!ENTITY coupe   "&#255;"><!-- endroit ou on peut couper un equation-->
]>


<xsl:stylesheet version="1.0"
xmlns:xsl='http://www.w3.org/1999/XSL/Transform' 
xmlns:saxon='http://icl.com/saxon'
xmlns:m='http://www.w3.org/1998/Math/MathML'
xmlns:lit='espacelit'
xmlns:doc='espaceDoc'>

<xsl:output method="text" encoding="UTF-8" indent="no"/>

<xsl:template match="lit">
	<!--<xsl:text>debLit</xsl:text>-->
	<xsl:apply-templates select="@*|*|text()|processing-instruction()" />
	<!--<xsl:text>FinLit</xsl:text>-->
</xsl:template>

<xsl:template match="phrase">
	<xsl:apply-templates />
	<xsl:text>&#13;&#10;</xsl:text>
</xsl:template>

<xsl:template match="ponctuation">
	<xsl:choose>
<!-- pts de suspension; -->
     <xsl:when test=".='...' or .='…' or .='&mldr;' or .='&vellip;' or .='&hellip;' or .='&dtdot;' or .='&ldots;' or .='&ctdot;' or .='&utdot;'">
       <xsl:text>&pt256;&pt256;&pt256;</xsl:text>
     </xsl:when>
		<xsl:when test='string(.)="&apos;"'>
			<xsl:text>&pt3;</xsl:text>
		</xsl:when>
		<xsl:when test=".='['">
			<xsl:text>&pt45;&pt236;</xsl:text>
		</xsl:when>
		<xsl:when test=".=']'">
			<xsl:text>&pt356;&pt12;</xsl:text>
		</xsl:when>
		<xsl:when test=".='{'">
			<xsl:text>&pt6;&pt6;&pt236;</xsl:text>
		</xsl:when>
		<xsl:when test=".='}'">
			<xsl:text>&pt356;&pt3;&pt3;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="translate(string(.),',;:.?-!&quot;«»“”‘’&lsquo;&rsquo;&acute;&prime;()','&pt2;&pt23;&pt25;&pt256;&pt26;&pt36;&pt235;&pt2356;&pt2356;&pt2356;&pt2356;&pt2356;&pt2356;&pt2356;&pt3;&pt3;&pt3;&pt3;&pt236;&pt356;')"/>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="not (local-name(following::*[1])='phrase')">
		<xsl:text> </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="mot">
	<xsl:choose>
		<xsl:when test="string-length(.)=0">
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test="contains('0123456789',substring(string(.),1,1))">
				<xsl:text>&pt6;</xsl:text>
			</xsl:if>
			<xsl:call-template name="majuscule">
				<xsl:with-param name="mot" select="string(.)" />
				<xsl:with-param name="prefixe" select="0" />
				<xsl:with-param name="position" select="1" />
			</xsl:call-template>
			<xsl:if test="local-name(following::*[1])='mot'">
				<xsl:text> </xsl:text>
			</xsl:if>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="symbolesComposes">
	<xsl:param name="mot"/>
	<xsl:choose>
		<xsl:when test="contains('–©°§®™&amp;~*#%‰_\¢€£$¥&lt;&gt;≤≥',string($mot))">
			<xsl:choose>
				<xsl:when test="substring($mot,1,1)='–'">
					<xsl:text>&pt36;&pt36;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='©'">
					<xsl:text>&pt5;&pt14;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='°'">
					<xsl:text>&pt5;&pt135;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='§'">
					<xsl:text>&pt5;&pt1234;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='®'">
					<xsl:text>&pt5;&pt1235;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='™'">
					<xsl:text>&pt5;&pt2345;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='&amp;'">
					<xsl:text>&pt5;&pt123456;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='~'">
					<xsl:text>&pt5;&pt26;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='*'">
					<xsl:text>&pt5;&pt35;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='#'">
					<xsl:text>&pt5;&pt3456;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='%'">
					<xsl:text>&pt5;&pt346;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='‰'">
					<xsl:text>&pt5;&pt346;&pt346;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='_'">
					<xsl:text>&pt5;&pt36;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='\'">
					<xsl:text>&pt5;&pt34;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='¢'">
					<xsl:text>&pt45;&pt14;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='€'">
					<xsl:text>&pt45;&pt15;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='£'">
					<xsl:text>&pt45;&pt123;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='$'">
					<xsl:text>&pt45;&pt234;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='¥'">
					<xsl:text>&pt45;&pt13456;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='&lt;'">
					<xsl:text>&pt5;&pt126;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='&gt;'">
					<xsl:text>&pt5;&pt345;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='≤'">
					<xsl:text>&pt45;&pt126;</xsl:text>
				</xsl:when>
				<xsl:when test="substring($mot,1,1)='≥'">
					<xsl:text>&pt45;&pt345;</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="bijection">
						<xsl:with-param name="mot" select="substring($mot,1,1)"/>
					</xsl:call-template>
					<xsl:call-template name="symbolesComposes">
						<xsl:with-param name="mot" select="substring($mot,2,string-length($mot))"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="bijection">
				<xsl:with-param name="mot" select="string($mot)"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="bijection">
	<xsl:param name="mot"/>
	<xsl:choose>
		<xsl:when test='string(.)="&apos;"'>
			<xsl:text>&pt2356;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="translate(string($mot),'ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜabcdefghijklmnopqrstuvwxyz0123456789àâéèêëîïôùûüçæœ@+-×÷=','&pt1;&pt12;&pt14;&pt145;&pt15;&pt124;&pt1245;&pt125;&pt24;&pt245;&pt13;&pt123;&pt134;&pt1345;&pt135;&pt1234;&pt12345;&pt1235;&pt234;&pt2345;&pt136;&pt1236;&pt2456;&pt1346;&pt13456;&pt1356;&pt12356;&pt16;&pt123456;&pt2346;&pt126;&pt1246;&pt146;&pt12456;&pt1456;&pt23456;&pt156;&pt1256;&pt1;&pt12;&pt14;&pt145;&pt15;&pt124;&pt1245;&pt125;&pt24;&pt245;&pt13;&pt123;&pt134;&pt1345;&pt135;&pt1234;&pt12345;&pt1235;&pt234;&pt2345;&pt136;&pt1236;&pt2456;&pt1346;&pt13456;&pt1356;&pt3456;&pt16;&pt126;&pt146;&pt1456;&pt156;&pt1246;&pt12456;&pt1256;&pt246;&pt12356;&pt16;&pt123456;&pt2346;&pt126;&pt1246;&pt146;&pt12456;&pt1456;&pt23456;&pt156;&pt1256;&pt12346;&pt345;&pt246;&pt345;&pt235;&pt36;&pt35;&pt25;&pt2356;')" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="majuscule">
	<xsl:param name="mot"/>
	<xsl:param name="prefixe"/>
	<xsl:param name="position"/>
<!--
	<xsl:value-of select='$mot'/>
	<xsl:if test="contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ ',$mot) and not(contains('abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûüçæœ',$mot))">
		<xsl:text>d&pt46;</xsl:text>
		<xsl:choose>
			<xsl:when test="contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ',following::*[1]) and not(contains('abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûüçæœ',following::*[1])) and contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ',following::*[2]) and not(contains('abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûüçæœ',following::*[2])) and contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ',following::*[3]) and not(contains('abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûüçæœ',following::*[3]))and not((contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ',preceding::*[1])) and not(contains('abcdefghijklmnopqrstuvwxyzàâéèêëîïôùûüçæœ',preceding::*[1])))">
				<xsl:text>YOP&pt46;</xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:if>

	<xsl:call-template name="symbolesComposes">
		<xsl:with-param name="mot" select="string(.)"/>
	</xsl:call-template>
-->
	<xsl:choose>
		<xsl:when test="string($position) > string(string-length($mot))">
			<xsl:if test="string($prefixe) ='0'">
				<xsl:text>&pt46;</xsl:text>
				<xsl:if test="string-length(.) > 1">
					<xsl:text>&pt46;</xsl:text>
				</xsl:if>
				<xsl:call-template name="symbolesComposes">
					<xsl:with-param name="mot" select="string(.)"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:when>
		<xsl:when test="string($prefixe)= '1'">
			<xsl:if test="contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ',substring(string($mot),$position,1))">
				<xsl:text>&pt46;</xsl:text>
			</xsl:if>
			<xsl:call-template name="symbolesComposes">
				<xsl:with-param name="mot" select="substring(string($mot),$position,1)"/>
			</xsl:call-template>
			<xsl:call-template name="majuscule">
				<xsl:with-param name="mot" select="$mot" />
				<xsl:with-param name="prefixe" select="1" />
				<xsl:with-param name="position" select="$position + 1" />
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="contains('ABCDEFGHIJKLMNOPQRSTUVWXYZÀÂÉÈÊËÎÏÔÙÛÜ',substring(string($mot),$position,1))">
			<xsl:call-template name="majuscule">
				<xsl:with-param name="mot" select="$mot" />
				<xsl:with-param name="prefixe" select="0" />
				<xsl:with-param name="position" select="$position + 1" />
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
<!---->
			<!-- on recommence au début du mot et cette fois on préfixe toutes les majuscules -->
<!---->
			<xsl:call-template name="majuscule">
				<xsl:with-param name="mot" select="$mot" />
				<xsl:with-param name="prefixe" select="1" />
				<xsl:with-param name="position" select="1" />
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
<!---->
</xsl:template>

</xsl:stylesheet>